@@ -13,7 +13,8 @@ def validated_choice(choices=["Yes","No"],
            overwrite_choices_display=None, 
            choices_size=1.0, 
            choices_color="black", 
-           y=0, height=-2, 
+           long_choices=False, width_raw = 15,
+           y=0, x=0, height=-2, 
            boxes_space=0.5, 
            boxes_background='white', 
            boxes_edge_color="black", 
@@ -107,44 +108,67 @@ def validated_choice(choices=["Yes","No"],
         title_position = "top"
     previous_mouse_state = pygame.mouse.set_visible(True)
 
-
-    list_x = [-10+boxes_space/2]
-    for i in range(number-1):
-        list_x.append(list_x[i]+  (20-boxes_space*number)/number + boxes_space)
-    list_x2 = []
-    for i in list_x:
-        list_x2.append(Coordinates.to_pygame(x=i))
-
-
-    coordinates = {
-    'x':list_x2,
-    'y':number*[Coordinates.to_pygame(y=y)],
-    'width_raw':(20-boxes_space*number)/number,
-    'height_raw':distance_y,
-    'width':Coordinates.to_pygame(distance_x=(20-boxes_space*number)/number),
-    'height':Coordinates.to_pygame(distance_y=distance_y)
-    }
-
-    if number == 2:
+    if long_choices == False:
+        
+        list_x = [-10+boxes_space/2]
+        for i in range(number-1):
+            list_x.append(list_x[i]+  (20-boxes_space*number)/number + boxes_space)
+        list_x2 = []
+        for i in list_x:
+            list_x2.append(Coordinates.to_pygame(x=i))
+            
         coordinates = {
-    'x':[Coordinates.to_pygame(x=-5.1),Coordinates.to_pygame(x=0.6)],
-    'y':number*[Coordinates.to_pygame(y=y)],
-    'width_raw':4.4,
-    'height_raw':distance_y,
-    'width':Coordinates.to_pygame(distance_x=4.4),
-    'height':Coordinates.to_pygame(distance_y=distance_y)
-    }
+        'x':list_x2,
+        'y':number*[Coordinates.to_pygame(y=y)],
+        'width_raw':(20-boxes_space*number)/number,
+        'height_raw':distance_y,
+        'width':Coordinates.to_pygame(distance_x=(20-boxes_space*number)/number),
+        'height':Coordinates.to_pygame(distance_y=distance_y)
+        }
+    
+        if number == 2:
+            coordinates = {
+        'x':[Coordinates.to_pygame(x=-5.1),Coordinates.to_pygame(x=0.6)],
+        'y':number*[Coordinates.to_pygame(y=y)],
+        'width_raw':4.4,
+        'height_raw':distance_y,
+        'width':Coordinates.to_pygame(distance_x=4.4),
+        'height':Coordinates.to_pygame(distance_y=distance_y)
+        }
+            
+    else:
+     
+        list_y = [1]
+        for i in range(number-1):
+            list_y.append(list_y[i]-(i+1)*2.5)
+        list_y2 = []
+        for i in list_y:
+            list_y2.append(Coordinates.to_pygame(y=i))
+            
+        coordinates = {
+        'x':number*[Coordinates.to_pygame(x=x-width_raw/2)],
+        'y':list_y2,
+        'width_raw':width_raw,
+        'height_raw':distance_y,
+        'width':Coordinates.to_pygame(distance_x=width_raw),
+        'height':Coordinates.to_pygame(distance_y=distance_y)
+        }
+    
+   
 
     width_confirm = 4
     coordinates_validate = {'x': Coordinates.to_pygame(x=width_confirm/2),
                             'y': Coordinates.to_pygame(y=-5),
                             'width': Coordinates.to_pygame(distance_x=width_confirm),
                             'height': coordinates['height']}
+    
+    '''
     coordinates_change = {'x': Coordinates.to_pygame(x=-3*width_confirm/2),
                           'y': Coordinates.to_pygame(y=-5),
                           'width': Coordinates.to_pygame(distance_x=width_confirm),
                           'height': coordinates['height']}
-
+    '''
+    
     def Display():
 
         for i in range(number):
@@ -241,8 +265,8 @@ def validated_choice(choices=["Yes","No"],
             x, y = pygame.mouse.get_pos()
             
             if help_list != None:
-                if y > coordinates['y'][0] and y < (coordinates['y'][0]+coordinates['height']):
-                        for i in range(number):
+                for i in range(number):
+                    if y > coordinates['y'][i] and y < (coordinates['y'][i]+coordinates['height']):                    
                             if x < (coordinates['x'][i] + coordinates['width']) and x > coordinates['x'][i]:
                                 pygame.draw.rect(screen, 
                                                  color(help_background), 
@@ -258,13 +282,12 @@ def validated_choice(choices=["Yes","No"],
       
          
             if pygame.mouse.get_pressed()==(1,0,0):
-                if y > coordinates['y'][0] and y < (coordinates['y'][0]+coordinates['height']):
-                    for i in range(number):
+                for i in range(number):
+                    if y > coordinates['y'][i] and y < (coordinates['y'][i]+coordinates['height']):                    
                         if x < (coordinates['x'][i] + coordinates['width']) and x > coordinates['x'][i]:
-                            
-                            
+                                
                             response = i
-                         
+
                             pygame.draw.rect(screen, 
                                              color(confirm_edge_color), 
                                              (coordinates['x'][response],
@@ -276,11 +299,12 @@ def validated_choice(choices=["Yes","No"],
                             write("Presser ESPACE pour passer à la question suivante.",
                                   y = -5,
                                   color=choices_color,
-                                  size=choices_size/2)
+                                  size=0.5)
+                            
                             write("Clic droit pour changer de réponse.",
                                   y = -6,
                                   color=choices_color,
-                                  size=choices_size/2)                        
+                                  size=0.5)                        
                             pygame.display.flip()
                           
                             loop2 = True
@@ -289,7 +313,7 @@ def validated_choice(choices=["Yes","No"],
                                 
                                 for event in pygame.event.get():
                                     if event.type == pygame.KEYDOWN:
-                                        print(event.key)
+                                        #print(event.key)
                                         if event.key == 32:
                                             loop = False
                                             loop2 = False
